==> api-v23.1.0-sources.jar: com/rivet/api/resources/group/invites/InvitesClient.java <==
package com.rivet.api.resources.group.invites;

import com.rivet.api.core.ApiError;
import com.rivet.api.core.ClientOptions;
import com.rivet.api.core.ObjectMappers;
import com.rivet.api.core.RequestOptions;
import com.rivet.api.resources.group.invites.types.ConsumeInviteResponse;
import com.rivet.api.resources.group.invites.types.CreateInviteRequest;
import com.rivet.api.resources.group.invites.types.CreateInviteResponse;
import com.rivet.api.resources.group.invites.types.GetInviteResponse;
import java.io.IOException;
import java.util.UUID;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

public class InvitesClient {
    protected final ClientOptions clientOptions;

    public InvitesClient(ClientOptions clientOptions) {
        this.clientOptions = clientOptions;
    }

    public GetInviteResponse getInvite(String groupInviteCode) {
        return getInvite(groupInviteCode, null);
    }

    public GetInviteResponse getInvite(String groupInviteCode, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getgroupURL())
                .newBuilder()
                .addPathSegments("invites")
                .addPathSegment(groupInviteCode)
                .build();
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("GET", null)
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), GetInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public ConsumeInviteResponse consumeInvite(String groupInviteCode) {
        return consumeInvite(groupInviteCode, null);
    }

    public ConsumeInviteResponse consumeInvite(String groupInviteCode, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getgroupURL())
                .newBuilder()
                .addPathSegments("invites")
                .addPathSegment(groupInviteCode)
                .addPathSegments("consume")
                .build();
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("POST", RequestBody.create("", null))
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), ConsumeInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public CreateInviteResponse createInvite(UUID groupId, CreateInviteRequest request) {
        return createInvite(groupId, request, null);
    }

    public CreateInviteResponse createInvite(UUID groupId, CreateInviteRequest request, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getgroupURL())
                .newBuilder()
                .addPathSegments("groups")
                .addPathSegment(groupId.toString())
                .addPathSegments("invites")
                .build();
        RequestBody _requestBody;
        try {
            _requestBody = RequestBody.create(
                    ObjectMappers.JSON_MAPPER.writeValueAsBytes(request), MediaType.parse("application/json"));
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("POST", _requestBody)
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), CreateInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}

==> api-23.2.0-rc1-sources.jar: com/rivet/api/resources/group/invites/InvitesClient.java <==
package com.rivet.api.resources.group.invites;

import com.rivet.api.core.ApiError;
import com.rivet.api.core.ClientOptions;
import com.rivet.api.core.ObjectMappers;
import com.rivet.api.core.RequestOptions;
import com.rivet.api.resources.group.invites.types.ConsumeInviteResponse;
import com.rivet.api.resources.group.invites.types.CreateInviteRequest;
import com.rivet.api.resources.group.invites.types.CreateInviteResponse;
import com.rivet.api.resources.group.invites.types.GetInviteResponse;
import java.io.IOException;
import java.util.UUID;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

public class InvitesClient {
    protected final ClientOptions clientOptions;

    public InvitesClient(ClientOptions clientOptions) {
        this.clientOptions = clientOptions;
    }

    public GetInviteResponse getInvite(String groupInviteCode) {
        return getInvite(groupInviteCode, null);
    }

    public GetInviteResponse getInvite(String groupInviteCode, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getUrl())
                .newBuilder()
                .addPathSegments("group")
                .addPathSegments("invites")
                .addPathSegment(groupInviteCode)
                .build();
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("GET", null)
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), GetInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public ConsumeInviteResponse consumeInvite(String groupInviteCode) {
        return consumeInvite(groupInviteCode, null);
    }

    public ConsumeInviteResponse consumeInvite(String groupInviteCode, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getUrl())
                .newBuilder()
                .addPathSegments("group")
                .addPathSegments("invites")
                .addPathSegment(groupInviteCode)
                .addPathSegments("consume")
                .build();
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("POST", RequestBody.create("", null))
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), ConsumeInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public CreateInviteResponse createInvite(UUID groupId, CreateInviteRequest request) {
        return createInvite(groupId, request, null);
    }

    public CreateInviteResponse createInvite(UUID groupId, CreateInviteRequest request, RequestOptions requestOptions) {
        HttpUrl _httpUrl = HttpUrl.parse(this.clientOptions.environment().getUrl())
                .newBuilder()
                .addPathSegments("group")
                .addPathSegments("groups")
                .addPathSegment(groupId.toString())
                .addPathSegments("invites")
                .build();
        RequestBody _requestBody;
        try {
            _requestBody = RequestBody.create(
                    ObjectMappers.JSON_MAPPER.writeValueAsBytes(request), MediaType.parse("application/json"));
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        Request _request = new Request.Builder()
                .url(_httpUrl)
                .method("POST", _requestBody)
                .headers(Headers.of(clientOptions.headers(requestOptions)))
                .addHeader("Content-Type", "application/json")
                .build();
        try {
            Response _response = clientOptions.httpClient().newCall(_request).execute();
            if (_response.isSuccessful()) {
                return ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), CreateInviteResponse.class);
            }
            throw new ApiError(
                    _response.code(),
                    ObjectMappers.JSON_MAPPER.readValue(_response.body().string(), Object.class));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
